==> json-schema-validator-1.3.3-sources.jar: org/eel/kitchen/jsonschema/keyword/draftv3/DisallowKeywordValidator.java <==
/*
 * Copyright (c) 2012, Francis Galiegue <fgaliegue@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.eel.kitchen.jsonschema.keyword.draftv3;

import com.fasterxml.jackson.databind.JsonNode;
import org.eel.kitchen.jsonschema.report.Message;
import org.eel.kitchen.jsonschema.report.ValidationReport;
import org.eel.kitchen.jsonschema.util.NodeType;
import org.eel.kitchen.jsonschema.validator.JsonValidator;
import org.eel.kitchen.jsonschema.validator.ValidationContext;

/**
 * Validator for the {@code disallow} keyword
 *
 * <p>{@code disallow} is the exact opposite of {@code type},
 * and if the JSON instance matches either a primitive type or a schema
 * within this keyword's definition, validation fails.</p>
 *
 */
public final class DisallowKeywordValidator
    extends AbstractTypeKeywordValidator
{
    public DisallowKeywordValidator(final JsonNode schema)
    {
        super("disallow", schema);
    }

    @Override
    public void validate(final ValidationContext context,
        final ValidationReport report, final JsonNode instance)
    {
        final Message.Builder msg;

        final NodeType type = NodeType.getNodeType(instance);
        if (typeSet.contains(type)) {
            msg = newMsg().addInfo("found", type).addInfo("disallowed", typeSet)
                .setMessage("instance type is not allowed");
            report.addMessage(msg.build());
            return;
        }

        if (schemas.isEmpty())
            return;

        ValidationReport schemaReport;
        JsonValidator validator;

        for (final JsonNode schema: schemas) {
            validator = context.newValidator(schema);
            schemaReport = report.copy();
            validator.validate(context, schemaReport, instance);
            if (schemaReport.hasFatalError()) {
                report.mergeWith(schemaReport);
                return;
            }
            if (schemaReport.isSuccess()) {
                msg = newMsg().setMessage("instance is valid against a " +
                    "disallowed schema");
                report.addMessage(msg.build());
                return;
            }
        }
    }
}

==> json-schema-validator-1.4.5-sources.jar: org/eel/kitchen/jsonschema/keyword/draftv3/DisallowKeywordValidator.java <==
/*
 * Copyright (c) 2012, Francis Galiegue <fgaliegue@gmail.com>
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the Lesser GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * Lesser GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

package org.eel.kitchen.jsonschema.keyword.draftv3;

import com.fasterxml.jackson.databind.JsonNode;
import org.eel.kitchen.jsonschema.report.Message;
import org.eel.kitchen.jsonschema.report.ValidationReport;
import org.eel.kitchen.jsonschema.util.NodeType;
import org.eel.kitchen.jsonschema.validator.JsonValidator;
import org.eel.kitchen.jsonschema.validator.ValidationContext;

/**
 * Validator for the {@code disallow} keyword
 *
 * <p>{@code disallow} is the exact opposite of {@code type}, and if the JSON
 * instance matches either a primitive type or a schema within this keyword's
 * definition, validation fails.</p>
 *
 */
public final class DisallowKeywordValidator
    extends AbstractTypeKeywordValidator
{
    public DisallowKeywordValidator(final JsonNode schema)
    {
        super("disallow", schema);
    }

    @Override
    public void validate(final ValidationContext context,
        final ValidationReport report, final JsonNode instance)
    {
        final Message.Builder msg;

        final NodeType type = NodeType.getNodeType(instance);
        if (typeSet.contains(type)) {
            msg = newMsg().addInfo("found", type).addInfo("disallowed", typeSet)
                .setMessage("instance type is not allowed");
            report.addMessage(msg.build());
            return;
        }

        if (schemas.isEmpty())
            return;

        ValidationReport schemaReport;
        JsonValidator validator;

        for (final JsonNode schema: schemas) {
            validator = context.newValidator(schema);
            schemaReport = report.copy();
            validator.validate(context, schemaReport, instance);
            if (schemaReport.hasFatalError()) {
                report.mergeWith(schemaReport);
                return;
            }
            if (schemaReport.isSuccess()) {
                msg = newMsg().setMessage("instance is valid against a " +
                    "disallowed schema");
                report.addMessage(msg.build());
                return;
            }
        }
    }
}
